@@ -18,7 +18,7 @@ print.pwrtsd <- function(x, ...)
       cat("No futility criterion\n")
     }
     cat("BE acceptance range = ", x$theta1," ... ", x$theta2,"\n\n", sep="")
-    cat("CV= ", x$CV,"; n(s1, s2)= ", x$n[1]," " , x$n[2], "\n", sep="")
+    cat("CV= "); cat(x$CV); cat("; n(s1, s2)= ", x$n[1]," " , x$n[2], "\n", sep="")
 
     # no sample size distribution in results here
     .print_results(x)
@@ -88,18 +88,19 @@ print.pwrtsd <- function(x, ...)
       cat("CV1 and GMR =", x$GMR, "in sample size est. used\n")
 
     # futility criterion w.r.t. PE or CI or Nmax
-    if(!is.null(x$fCrit)){
-      if(is.finite(x$fCNmax)) {
+    if ("no" %in% x$fCrit) {
+      cat("No futility criterion regarding PE, CI or Nmax\n")
+    } else {
+      if (is.finite(x$fCNmax)) {
         cat("Futility criterion Nmax = ",x$fCNmax,"\n", sep="")
       } else {
         cat("No futility criterion regarding Nmax\n")
       }
-      if(x$fCrange[1L] >0 & is.finite(x$fCrange[2L])){
+      if (x$fCrange[1L] > 0 && is.finite(x$fCrange[2L])) {
         fCrit <- x$fCrit
-        #fCrit <- if ("ci" %in% fCrit) "(1 - 2*alpha_s1) CI" else if ("pe" %in% fCrit) "PE"
         fCrit <- if ("ci" %in% fCrit) "90% CI" else if ("pe" %in% fCrit) "PE"
         cat("Futility criterion ", fCrit," outside ", x$fCrange[1L], " ... ",
-            x$fCrange[2L], "\n", sep="")
+            x$fCrange[2L], "\n", sep = "")
       } else {
         cat("No futility criterion regarding PE or CI\n")
       }
@@ -143,7 +144,7 @@ print.pwrtsd <- function(x, ...)
 
   # power.2stage.p()
   if(!is.null(x$test)){
-    cat("CI's based on", ifelse(x$test=="welch","Welch's t-test", x$test),"\n")
+    cat("CIs based on", ifelse(x$test=="welch","Welch's t-test", x$test),"\n")
   }
   if(is.null(x$powerstep)){
     cat("Target power in power monitoring and sample size est. = ",
@@ -217,7 +218,9 @@ print.pwrtsd <- function(x, ...)
   if(!is.null(x$usePE)) {
     if(x$usePE==TRUE) x$GMR <- NULL
   }
-  if(!is.null(x$GMR)) cat("; GMR=", x$GMR, "\n") else cat("\n")
+  if(!is.null(x$GMR)) {
+    cat("; GMR = "); cat(x$GMR, sep=", "); cat("\n")
+  } else cat("\n")
 
   .print_results(x)
 
@@ -243,8 +246,11 @@ print.pwrtsd <- function(x, ...)
 .print_results <- function(x)
 {
   # --- results part
-  cat("\n", x$nsims," sims at theta0 = ", x$theta0, sep="")
-  if(x$theta0<=x$theta1 | x$theta0>=x$theta2) cat(" (p(BE) = TIE 'alpha').\n") else {
+  # theta0 may have more then one element
+  th0str <- paste(x$theta0, collapse=", ")
+  cat("\n", x$nsims," sims at theta0 = ", th0str, sep="")
+  if(any(x$theta0<=x$theta1) | any(x$theta0>=x$theta2))
+    cat(" (p(BE) = TIE 'alpha').\n") else {
     cat(" (p(BE) = 'power').\n")}
   cat("p(BE)    = ", x$pBE,"\n", sep="")
   # power.2stage.ssr() has no pBE_s1
